Package: spsur
Type: Package
Title: Spatial Seemingly Unrelated Regression Models
Version: 1.0.2.6
Date: 2025-09-02
Authors@R: c(person("Ana", "Angulo", email = "aangulo@unizar.es", 
                  role = "aut"),
           person("Fernando A", "Lopez", email = "fernando.lopez@upct.es", 
                  role = "aut"), 
           person("Roman", "Minguez", email = "roman.minguez@uclm.es", 
                  role = c("aut", "cre")),
           person("Jesus", "Mur", email = "jmur@unizar.es", 
                  role = "aut"))
Maintainer: Roman Minguez <roman.minguez@uclm.es>
Description: A collection of functions to test and estimate Seemingly 
    Unrelated Regression (usually called SUR) models, with spatial structure, by maximum 
    likelihood and three-stage least squares. The package estimates the 
    most common spatial specifications, that is, SUR with Spatial Lag of 
    X regressors (called SUR-SLX), SUR with Spatial Lag Model (called SUR-SLM), 
    SUR with Spatial Error Model (called SUR-SEM), SUR with Spatial Durbin Model (called SUR-SDM), 
    SUR with Spatial Durbin Error Model (called SUR-SDEM), 
    SUR with Spatial Autoregressive terms and Spatial Autoregressive 
    Disturbances (called SUR-SARAR), SUR-SARAR with Spatial Lag of X 
    regressors (called SUR-GNM) and SUR with Spatially Independent Model (called SUR-SIM).
    The methodology of these models can be found in next references 
    Minguez, R., Lopez, F.A., and Mur, J. (2022) <doi:10.18637/jss.v104.i11>
    Mur, J., Lopez, F.A., and Herrera, M. (2010) <doi:10.1080/17421772.2010.516443> 
    Lopez, F.A., Mur, J., and Angulo, A. (2014) <doi:10.1007/s00168-014-0624-2>.
LazyData: true
Encoding: UTF-8
License: GPL-3
Depends: R (>= 4.1), methods (>= 4.1), stats (>= 4.1)
Imports: Formula (>= 1.2-5), ggplot2 (>= 3.5.2), gmodels (>= 2.19.1),
        gridExtra (>= 2.3), MASS (>= 7.3-65), Matrix (>= 1.4-1), minqa
        (>= 1.2.8), numDeriv (>= 2016.8-1.1), Rdpack (>= 2.6.4), rlang
        (>= 1.1.6), sparseMVN (>= 0.2.2), spatialreg (>= 1.3-6), spdep
        (>= 1.4-1), sphet(>= 2.1-1)
Suggests: bookdown (>= 0.44), dplyr (>= 1.1.4), kableExtra (>= 1.4.0),
        knitr (>= 1.50), rmarkdown (>= 2.29), sf (>= 1.0-20)
VignetteBuilder: knitr
RoxygenNote: 7.3.2
RdMacros: Rdpack
URL: https://CRAN.R-project.org/package=spsur
BugReports: https://github.com/rominsal/spsur/issues
NeedsCompilation: no
Packaged: 2025-09-03 09:01:44 UTC; roman
Author: Ana Angulo [aut],
  Fernando A Lopez [aut],
  Roman Minguez [aut, cre],
  Jesus Mur [aut]
Repository: CRAN
Date/Publication: 2025-09-03 09:20:02 UTC
Built: R 4.6.0; ; 2026-04-28 11:46:34 UTC; unix
